@@ -58,14 +58,14 @@ class Schedule(AbstractObject):
         if self.fallback_action is None:
             dialaction = {
                 'schedule_fallback': {
-                        "actiontype": 'none'
+                    "actiontype": 'none'
                 }
             }
         else:
             dialaction = {
                 'schedule_fallback': {
-                        "actiontype": self.fallback_action.split(':')[0],
-                        "action": self.fallback_action.split(':')[1]
+                    "actiontype": self.fallback_action.split(':')[0],
+                    "action": self.fallback_action.split(':')[1]
                 }
             }
         obj_dict['dialaction'] = dialaction
@@ -86,7 +86,7 @@ class Schedule(AbstractObject):
 
     def _from_schedule(self, schedule):
         self.id = int(schedule['id'])
-        self.entity_id = int(schedule['entity_id'])
+        self.entity_id = int(schedule['entity_id']) if schedule['entity_id'] else None
         self.name = schedule['name']
         self.timezone = schedule['timezone']
         self.fallback_action = schedule['fallback_action']
